@@ -10,6 +10,8 @@
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ *
+ * RCS: @(#) $Id: tkColor.c,v 1.16 2007/12/13 15:24:13 dgp Exp $
  */
 
 #include "tkInt.h"
@@ -40,11 +42,10 @@ static Tcl_ThreadDataKey dataKey;
  * Forward declarations for functions defined in this file:
  */
 
-static void		ColorInit _ANSI_ARGS_((TkDisplay *dispPtr));
-static void		DupColorObjProc _ANSI_ARGS_((Tcl_Obj *srcObjPtr,
-			    Tcl_Obj *dupObjPtr));
-static void		FreeColorObjProc _ANSI_ARGS_((Tcl_Obj *objPtr));
-static void		InitColorObj _ANSI_ARGS_((Tcl_Obj *objPtr));
+static void		ColorInit(TkDisplay *dispPtr);
+static void		DupColorObjProc(Tcl_Obj *srcObjPtr,Tcl_Obj *dupObjPtr);
+static void		FreeColorObjProc(Tcl_Obj *objPtr);
+static void		InitColorObj(Tcl_Obj *objPtr);
 
 /*
  * The following structure defines the implementation of the "color" Tcl
@@ -85,11 +86,11 @@ Tcl_ObjType tkColorObjType = {
  */
 
 XColor *
-Tk_AllocColorFromObj(interp, tkwin, objPtr)
-    Tcl_Interp *interp;		/* Used only for error reporting.  If NULL,
+Tk_AllocColorFromObj(
+    Tcl_Interp *interp,		/* Used only for error reporting. If NULL,
 				 * then no messages are provided. */
-    Tk_Window tkwin;		/* Window in which the color will be used.*/
-    Tcl_Obj *objPtr;		/* Object that describes the color; string
+    Tk_Window tkwin,		/* Window in which the color will be used.*/
+    Tcl_Obj *objPtr)		/* Object that describes the color; string
 				 * value is a color name such as "red" or
 				 * "#ff0000".*/
 {
@@ -128,8 +129,8 @@ Tk_AllocColorFromObj(interp, tkwin, objPtr)
      */
 
     if (tkColPtr != NULL) {
-	TkColor *firstColorPtr = 
-		(TkColor *) Tcl_GetHashValue(tkColPtr->hashPtr);
+	TkColor *firstColorPtr = (TkColor *)
+		Tcl_GetHashValue(tkColPtr->hashPtr);
 	FreeColorObjProc(objPtr);
 	for (tkColPtr = firstColorPtr; tkColPtr != NULL;
 		tkColPtr = tkColPtr->nextPtr) {
@@ -137,7 +138,7 @@ Tk_AllocColorFromObj(interp, tkwin, objPtr)
 		    && (Tk_Colormap(tkwin) == tkColPtr->colormap)) {
 		tkColPtr->resourceRefCount++;
 		tkColPtr->objRefCount++;
-		objPtr->internalRep.twoPtrValue.ptr1 = (VOID *) tkColPtr;
+		objPtr->internalRep.twoPtrValue.ptr1 = (void *) tkColPtr;
 		return (XColor *) tkColPtr;
 	    }
 	}
@@ -148,7 +149,7 @@ Tk_AllocColorFromObj(interp, tkwin, objPtr)
      */
 
     tkColPtr = (TkColor *) Tk_GetColor(interp, tkwin, Tcl_GetString(objPtr));
-    objPtr->internalRep.twoPtrValue.ptr1 = (VOID *) tkColPtr;
+    objPtr->internalRep.twoPtrValue.ptr1 = (void *) tkColPtr;
     if (tkColPtr != NULL) {
 	tkColPtr->objRefCount++;
     }
@@ -180,11 +181,11 @@ Tk_AllocColorFromObj(interp, tkwin, objPtr)
  */
 
 XColor *
-Tk_GetColor(interp, tkwin, name)
-    Tcl_Interp *interp;		/* Place to leave error message if color can't
+Tk_GetColor(
+    Tcl_Interp *interp,		/* Place to leave error message if color can't
 				 * be found. */
-    Tk_Window tkwin;		/* Window in which color will be used. */
-    Tk_Uid name;		/* Name of color to be allocated (in form
+    Tk_Window tkwin,		/* Window in which color will be used. */
+    Tk_Uid name)		/* Name of color to be allocated (in form
 				 * suitable for passing to XParseColor). */
 {
     Tcl_HashEntry *nameHashPtr;
@@ -234,7 +235,7 @@ Tk_GetColor(interp, tkwin, name)
 	if (isNew) {
 	    Tcl_DeleteHashEntry(nameHashPtr);
 	}
-	return (XColor *) NULL;
+	return NULL;
     }
 
     /*
@@ -281,9 +282,9 @@ Tk_GetColor(interp, tkwin, name)
  */
 
 XColor *
-Tk_GetColorByValue(tkwin, colorPtr)
-    Tk_Window tkwin;		/* Window where color will be used. */
-    XColor *colorPtr;		/* Red, green, and blue fields indicate
+Tk_GetColorByValue(
+    Tk_Window tkwin,		/* Window where color will be used. */
+    XColor *colorPtr)		/* Red, green, and blue fields indicate
 				 * desired color. */
 {
     ValueKey valueKey;
@@ -299,11 +300,8 @@ Tk_GetColorByValue(tkwin, colorPtr)
 
     /*
      * First, check to see if there's already a mapping for this color name.
-     * Must clear the structure first; it's not tightly packed on 64-bit
-     * systems. [Bug 2911570]
      */
 
-    memset(&valueKey, 0, sizeof(ValueKey));
     valueKey.red = colorPtr->red;
     valueKey.green = colorPtr->green;
     valueKey.blue = colorPtr->blue;
@@ -358,13 +356,12 @@ Tk_GetColorByValue(tkwin, colorPtr)
  */
 
 CONST char *
-Tk_NameOfColor(colorPtr)
-    XColor *colorPtr;		/* Color whose name is desired. */
+Tk_NameOfColor(
+    XColor *colorPtr)		/* Color whose name is desired. */
 {
     register TkColor *tkColPtr = (TkColor *) colorPtr;
 
-    if ((tkColPtr->magic == COLOR_MAGIC) &&
-	    (tkColPtr->type == TK_COLOR_BY_NAME)) {
+    if (tkColPtr->magic==COLOR_MAGIC && tkColPtr->type==TK_COLOR_BY_NAME) {
 	return tkColPtr->hashPtr->key.string;
     } else {
 	ThreadSpecificData *tsdPtr = (ThreadSpecificData *)
@@ -397,10 +394,10 @@ Tk_NameOfColor(colorPtr)
  */
 
 GC
-Tk_GCForColor(colorPtr, drawable)
-    XColor *colorPtr;		/* Color for which a GC is desired. Must have
+Tk_GCForColor(
+    XColor *colorPtr,		/* Color for which a GC is desired. Must have
 				 * been allocated by Tk_GetColor. */
-    Drawable drawable;		/* Drawable in which the color will be used
+    Drawable drawable)		/* Drawable in which the color will be used
 				 * (must have same screen and depth as the one
 				 * for which the color was allocated). */
 {
@@ -418,8 +415,8 @@ Tk_GCForColor(colorPtr, drawable)
 
     if (tkColPtr->gc == None) {
 	gcValues.foreground = tkColPtr->color.pixel;
-	tkColPtr->gc = XCreateGC(DisplayOfScreen(tkColPtr->screen), drawable,
-		GCForeground, &gcValues);
+	tkColPtr->gc = XCreateGC(DisplayOfScreen(tkColPtr->screen),
+		drawable, GCForeground, &gcValues);
     }
     return tkColPtr->gc;
 }
@@ -442,8 +439,8 @@ Tk_GCForColor(colorPtr, drawable)
  */
 
 void
-Tk_FreeColor(colorPtr)
-    XColor *colorPtr;		/* Color to be released.  Must have been
+Tk_FreeColor(
+    XColor *colorPtr)		/* Color to be released. Must have been
 				 * allocated by Tk_GetColor or
 				 * Tk_GetColorByValue. */
 {
@@ -524,10 +521,10 @@ Tk_FreeColor(colorPtr)
  */
 
 void
-Tk_FreeColorFromObj(tkwin, objPtr)
-    Tk_Window tkwin;		/* The window this color lives in. Needed
-				 * for the screen and colormap values. */
-    Tcl_Obj *objPtr;		/* The Tcl_Obj * to be freed. */
+Tk_FreeColorFromObj(
+    Tk_Window tkwin,		/* The window this color lives in. Needed for
+				 * the screen and colormap values. */
+    Tcl_Obj *objPtr)		/* The Tcl_Obj * to be freed. */
 {
     Tk_FreeColor(Tk_GetColorFromObj(tkwin, objPtr));
     FreeColorObjProc(objPtr);
@@ -553,8 +550,8 @@ Tk_FreeColorFromObj(tkwin, objPtr)
  */
 
 static void
-FreeColorObjProc(objPtr)
-    Tcl_Obj *objPtr;		/* The object we are releasing. */
+FreeColorObjProc(
+    Tcl_Obj *objPtr)		/* The object we are releasing. */
 {
     TkColor *tkColPtr = (TkColor *) objPtr->internalRep.twoPtrValue.ptr1;
 
@@ -564,7 +561,7 @@ FreeColorObjProc(objPtr)
 		&& (tkColPtr->resourceRefCount == 0)) {
 	    ckfree((char *) tkColPtr);
 	}
-	objPtr->internalRep.twoPtrValue.ptr1 = (VOID *) NULL;
+	objPtr->internalRep.twoPtrValue.ptr1 = NULL;
     }
 }
 
@@ -587,14 +584,14 @@ FreeColorObjProc(objPtr)
  */
 
 static void
-DupColorObjProc(srcObjPtr, dupObjPtr)
-    Tcl_Obj *srcObjPtr;		/* The object we are copying from. */
-    Tcl_Obj *dupObjPtr;		/* The object we are copying to. */
+DupColorObjProc(
+    Tcl_Obj *srcObjPtr,		/* The object we are copying from. */
+    Tcl_Obj *dupObjPtr)		/* The object we are copying to. */
 {
     TkColor *tkColPtr = (TkColor *) srcObjPtr->internalRep.twoPtrValue.ptr1;
 
     dupObjPtr->typePtr = srcObjPtr->typePtr;
-    dupObjPtr->internalRep.twoPtrValue.ptr1 = (VOID *) tkColPtr;
+    dupObjPtr->internalRep.twoPtrValue.ptr1 = (void *) tkColPtr;
 
     if (tkColPtr != NULL) {
 	tkColPtr->objRefCount++;
@@ -621,10 +618,10 @@ DupColorObjProc(srcObjPtr, dupObjPtr)
  */
 
 XColor *
-Tk_GetColorFromObj(tkwin, objPtr)
-    Tk_Window tkwin;		/* The window in which the color will be
+Tk_GetColorFromObj(
+    Tk_Window tkwin,		/* The window in which the color will be
 				 * used. */
-    Tcl_Obj *objPtr;		/* String value contains the name of the
+    Tcl_Obj *objPtr)		/* String value contains the name of the
 				 * desired color. */
 {
     TkColor *tkColPtr;
@@ -672,7 +669,7 @@ Tk_GetColorFromObj(tkwin, objPtr)
 	if ((Tk_Screen(tkwin) == tkColPtr->screen)
 		&& (Tk_Colormap(tkwin) == tkColPtr->colormap)) {
 	    FreeColorObjProc(objPtr);
-	    objPtr->internalRep.twoPtrValue.ptr1 = (VOID *) tkColPtr;
+	    objPtr->internalRep.twoPtrValue.ptr1 = (void *) tkColPtr;
 	    tkColPtr->objRefCount++;
 	    return (XColor *) tkColPtr;
 	}
@@ -705,10 +702,10 @@ Tk_GetColorFromObj(tkwin, objPtr)
  */
 
 static void
-InitColorObj(objPtr)
-    Tcl_Obj *objPtr;		/* The object to convert. */
+InitColorObj(
+    Tcl_Obj *objPtr)		/* The object to convert. */
 {
-    Tcl_ObjType *typePtr;
+    const Tcl_ObjType *typePtr;
 
     /*
      * Free the old internalRep before setting the new one.
@@ -720,7 +717,7 @@ InitColorObj(objPtr)
 	(*typePtr->freeIntRepProc)(objPtr);
     }
     objPtr->typePtr = &tkColorObjType;
-    objPtr->internalRep.twoPtrValue.ptr1 = (VOID *) NULL;
+    objPtr->internalRep.twoPtrValue.ptr1 = NULL;
 }
 
 /*
@@ -740,8 +737,8 @@ InitColorObj(objPtr)
  */
 
 static void
-ColorInit(dispPtr)
-    TkDisplay *dispPtr;
+ColorInit(
+    TkDisplay *dispPtr)
 {
     if (!dispPtr->colorInit) {
 	dispPtr->colorInit = 1;
@@ -771,10 +768,10 @@ ColorInit(dispPtr)
  */
 
 Tcl_Obj *
-TkDebugColor(tkwin, name)
-    Tk_Window tkwin;		/* The window in which the color will be used
+TkDebugColor(
+    Tk_Window tkwin,		/* The window in which the color will be used
 				 * (not currently used). */
-    char *name;			/* Name of the desired color. */
+    char *name)			/* Name of the desired color. */
 {
     Tcl_HashEntry *hashPtr;
     Tcl_Obj *resultPtr;
@@ -800,110 +797,7 @@ TkDebugColor(tkwin, name)
     }
     return resultPtr;
 }
-
-#ifndef __WIN32__
-
-/* This function is not necessary for Win32,
- * since XParseColor already does the right thing */
-
-#undef XParseColor
-
-CONST char *CONST tkWebColors[20] = {
-    /* 'a' */ "qua\0#0000ffffffff",
-    /* 'b' */ NULL,
-    /* 'c' */ "rimson\0#dcdc14143c3c",
-    /* 'd' */ NULL,
-    /* 'e' */ NULL,
-    /* 'f' */ "uchsia\0#ffff0000ffff",
-    /* 'g' */ NULL,
-    /* 'h' */ NULL,
-    /* 'i' */ "ndigo\0#4b4b00008282",
-    /* 'j' */ NULL,
-    /* 'k' */ NULL,
-    /* 'l' */ "ime\0#0000ffff0000",
-    /* 'm' */ NULL,
-    /* 'n' */ NULL,
-    /* 'o' */ "live\0#808080800000",
-    /* 'p' */ NULL,
-    /* 'q' */ NULL,
-    /* 'r' */ NULL,
-    /* 's' */ "ilver\0#c0c0c0c0c0c0",
-    /* 't' */ "eal\0#000080808080"
-};
-
-Status
-TkParseColor(display, map, name, color)
-    Display * display;		/* The display */
-    Colormap map;			/* Color map */
-    CONST char* name;     /* String to be parsed */
-    XColor * color;
-{
-    char buf[14];
-    if (*name == '#') {
-	buf[0] = '#'; buf[13] = '\0';
-	if (!*(++name) || !*(++name) || !*(++name)) {
-	    /* Not at least 3 hex digits, so invalid */
-	return 0;
-	} else if (!*(++name)) {
-	    /* Exactly 3 hex digits */
-	    buf[9] = buf[10] = buf[11] = buf[12] = *(--name);
-	    buf[5] = buf[6] = buf[7] = buf[8] = *(--name);
-	    buf[1] = buf[2] = buf[3] = buf[4] = *(--name);
-	    name = buf;
-	} else if (!*(++name)	|| !*(++name)) {
-	    /* Not at least 6 hex digits, so invalid */
-	    return 0;
-	} else if (!*(++name)) {
-	    /* Exactly 6 hex digits */
-	    buf[10] = buf[12] = *(--name);
-	    buf[9] = buf[11] = *(--name);
-	    buf[6] = buf[8] = *(--name);
-	    buf[5] = buf[7] = *(--name);
-	    buf[2] = buf[4] = *(--name);
-	    buf[1] = buf[3] = *(--name);
-	    name = buf;
-	} else if (!*(++name) || !*(++name)) {
-	    /* Not at least 9 hex digits, so invalid */
-	    return 0;
-	} else if (!*(++name)) {
-	    /* Exactly 9 hex digits */
-	    buf[11] = *(--name);
-	    buf[10] = *(--name);
-	    buf[9] = buf[12] = *(--name);
-	    buf[7] = *(--name);
-	    buf[6] = *(--name);
-	    buf[5] = buf[8] = *(--name);
-	    buf[3] = *(--name);
-	    buf[2] = *(--name);
-	    buf[1] = buf[4] = *(--name);
-	    name = buf;
-	} else if (!*(++name) || !*(++name) || *(++name)) {
-	    /* Not exactly 12 hex digits, so invalid */
-	    return 0;
-	} else {
-	    name -= 13;
-	}
-	goto done;
-    } else if (((*name - 'A') & 0xdf) < sizeof(tkWebColors)/sizeof(tkWebColors[0])) {
-	const char *p = tkWebColors[((*name - 'A') & 0x1f)];
-	if (p) {
-	    const char *q = name;
-	    while (!((*p - *(++q)) & 0xdf)) {
-		if (!*p++) {
-		    name = p;
-		    goto done;
-		}
-	    }
-	}
-    }
-    if (strlen(name) > 99) {
-	/* Don't bother to parse this. [Bug 2809525]*/
-	return 0;
-    }
-done:
-    return XParseColor(display, map, name, color);
-}
-#endif /* __WIN32__ */
+
 /*
  * Local Variables:
  * mode: c
