@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkPointer.c,v 1.10 2005/11/15 15:18:22 dkf Exp $
+ * RCS: @(#) $Id: tkPointer.c,v 1.10.4.1 2008/06/12 17:09:11 das Exp $
  */
 
 #include "tkInt.h"
@@ -309,14 +309,12 @@ Tk_UpdatePointer(
 
 		/*
 		 * ButtonRelease - Release the mouse capture and clear the
-		 * restrict window when the last button is released and we
-		 * aren't in a global grab.
+		 * restrict window when the last button is released. If we
+		 * are in a global grab, restore the grab window capture.
 		 */
 
 		if ((tsdPtr->lastState & ALL_BUTTONS) == mask) {
-		    if (!tsdPtr->grabWinPtr) {
-			TkpSetCapture(NULL);
-		    }
+		    TkpSetCapture(tsdPtr->grabWinPtr);
 		}
 
 		/*
