@@ -10,6 +10,8 @@
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ *
+ * RCS: @(#) $Id: tkMacOSXButton.c,v 1.32 2007/12/13 15:27:08 dgp Exp $
  */
 
 #include "tkMacOSXPrivate.h"
@@ -23,7 +25,7 @@
 #define FIRST_DRAW	    2
 #define ACTIVE		    4
 
-#define MAX_VALUE	    1
+#define MAX_VALUE	    2
 
 /*
  * Default insets for controls
@@ -363,12 +365,10 @@ TkpDisplayButton(
 	    if ((butPtr->selectImage != NULL) && (butPtr->flags & SELECTED)) {
 		Tk_RedrawImage(butPtr->selectImage, 0, 0, width, height,
 			pixmap, imageXOffset, imageYOffset);
-#if 0
 	    } else if ((butPtr->tristateImage != NULL) &&
 		    (butPtr->flags & TRISTATED)) {
 		Tk_RedrawImage(butPtr->tristateImage, 0, 0, width, height,
 			pixmap, imageXOffset, imageYOffset);
-#endif
 	    } else {
 		Tk_RedrawImage(butPtr->image, 0, 0, width, height,
 			pixmap, imageXOffset, imageYOffset);
@@ -412,12 +412,10 @@ TkpDisplayButton(
 	    if ((butPtr->selectImage != NULL) && (butPtr->flags & SELECTED)) {
 		Tk_RedrawImage(butPtr->selectImage, 0, 0, width, height,
 			pixmap, imageXOffset, imageYOffset);
-#if 0
 	    } else if ((butPtr->tristateImage != NULL) &&
 		    (butPtr->flags & TRISTATED)) {
 		Tk_RedrawImage(butPtr->tristateImage, 0, 0, width, height,
 			pixmap, imageXOffset, imageYOffset);
-#endif
 	    } else {
 		Tk_RedrawImage(butPtr->image, 0, 0, width, height,
 			pixmap, imageXOffset, imageYOffset);
@@ -488,7 +486,7 @@ TkpDisplayButton(
 
 	    Tk_Draw3DRectangle(tkwin, pixmap, dpPtr->border, inset, inset,
 		    Tk_Width(tkwin) - 2*inset, Tk_Height(tkwin) - 2*inset,
-		    borderWidth, dpPtr->relief);
+		    butPtr->borderWidth, dpPtr->relief);
 	}
     }
     if (portChanged) {
@@ -898,7 +896,7 @@ TkMacOSXDrawControl(
      * The control has been previously initialised.
      * It may need to be re-initialised
      */
-#if 0
+#ifdef TK_REBUILD_TOPLEVEL
     rebuild = (winPtr->flags & TK_REBUILD_TOPLEVEL);
     winPtr->flags &= ~TK_REBUILD_TOPLEVEL;
 #else
@@ -974,10 +972,8 @@ TkMacOSXDrawControl(
 
     if (butPtr->flags & SELECTED) {
 	SetControlValue(mbPtr->control, 1);
-#if 0
     } else if (butPtr->flags & TRISTATED) {
 	SetControlValue(mbPtr->control, 2);
-#endif
     } else {
 	SetControlValue(mbPtr->control, 0);
     }
@@ -1123,11 +1119,9 @@ SetupBevelButton(
 
     if (butPtr->selectImage != NULL && (butPtr->flags & SELECTED)) {
 	Tk_RedrawImage(butPtr->selectImage, 0, 0, width, height, pixmap, 0, 0);
-#if 0
     } else if (butPtr->tristateImage != NULL && (butPtr->flags & TRISTATED)) {
 	Tk_RedrawImage(butPtr->tristateImage, 0, 0, width, height, pixmap, 0,
 		0);
-#endif
     } else if (butPtr->image != NULL) {
 	Tk_RedrawImage(butPtr->image, 0, 0, width, height, pixmap, 0, 0);
     } else {
