@@ -6,10 +6,12 @@
  *
  * Copyright (c) 1995-1997 Sun Microsystems, Inc.
  * Copyright 2001, Apple Computer, Inc.
- * Copyright (c) 2006-2009 Daniel A. Steffen <das@users.sourceforge.net>
+ * Copyright (c) 2006 Daniel A. Steffen <das@users.sourceforge.net>
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ *
+ * RCS: @(#) $Id: tkMacOSXHLEvents.c,v 1.15 2007/12/13 15:27:09 dgp Exp $
  */
 
 #include "tkMacOSXPrivate.h"
@@ -204,7 +206,7 @@ OappHandler(
 
     if (interp &&
 	    Tcl_GetCommandInfo(interp, "::tk::mac::OpenApplication", &dummy)) {
-	Tcl_EvalEx(interp, "::tk::mac::OpenApplication", -1, TCL_EVAL_GLOBAL);
+	Tcl_GlobalEval(interp, "::tk::mac::OpenApplication");
     }
     return noErr;
 }
@@ -238,7 +240,7 @@ RappHandler(
 
     if (interp &&
 	    Tcl_GetCommandInfo(interp, "::tk::mac::ReopenApplication", &dummy)) {
-	Tcl_EvalEx(interp, "::tk::mac::ReopenApplication", -1, TCL_EVAL_GLOBAL);
+	Tcl_GlobalEval(interp, "::tk::mac::ReopenApplication");
     }
     return err;
 }
@@ -271,7 +273,7 @@ PrefsHandler(
 
     if (interp &&
 	    Tcl_GetCommandInfo(interp, "::tk::mac::ShowPreferences", &dummy)) {
-	Tcl_EvalEx(interp, "::tk::mac::ShowPreferences", -1, TCL_EVAL_GLOBAL);
+	Tcl_GlobalEval(interp, "::tk::mac::ShowPreferences");
     }
     return noErr;
 }
@@ -490,8 +492,8 @@ ScriptHandler(
     theErr = AEGetParamDesc(event, keyDirectObject, typeWildCard,
 	    &theDesc);
     if (theErr != noErr) {
-	sprintf(errString, "AEDoScriptHandler: GetParamDesc error %d",
-		(int)theErr);
+	sprintf(errString, "AEDoScriptHandler: GetParamDesc error %ld",
+		theErr);
 	theErr = AEPutParamPtr(reply, keyErrorString, typeChar, errString,
 		strlen(errString));
     } else if (MissedAnyParameters(event)) {
@@ -500,22 +502,54 @@ ScriptHandler(
 		strlen(errString));
 	theErr = -1771;
     } else {
-	Size size;
+	if (theDesc.descriptorType == (DescType)typeChar) {
+	    Tcl_DString encodedText;
+	    short i;
+	    Size  size;
+	    char  * data;
 
-	if (theDesc.descriptorType == (DescType)typeAlias &&
-		AEGetParamPtr(event, keyDirectObject, typeFSRef, NULL, NULL,
-		0, &size) == noErr && size == sizeof(FSRef)) {
+	    size = AEGetDescDataSize(&theDesc);
+
+	    data = (char *)ckalloc(size + 1);
+	    if ( !data ) {
+		theErr = -1771;
+	    }
+	    else {
+		   AEGetDescData(&theDesc,data,size);
+		   data [ size ] = 0;
+		   for (i = 0; i < size; i++)
+		    if (data[i] == '\r')
+		     data[i] = '\n';
+		   AEReplaceDescData(theDesc.descriptorType, data,
+			   size + 1, &theDesc);
+	    }
+	    Tcl_ExternalToUtfDString(NULL, data, size,
+		    &encodedText);
+	    tclErr = Tcl_EvalEx(interp, Tcl_DStringValue(&encodedText),
+		    Tcl_DStringLength(&encodedText), TCL_EVAL_GLOBAL);
+	    Tcl_DStringFree(&encodedText);
+	} else if (theDesc.descriptorType == (DescType)typeAlias) {
+	    Boolean dummy;
 	    FSRef file;
+	    AliasPtr	alias;
+	    Size	theSize;
 
-	    theErr = AEGetParamPtr(event, keyDirectObject, typeFSRef, NULL,
-		    &file, size, NULL);
+	    theSize = AEGetDescDataSize(&theDesc);
+	    alias = (AliasPtr) ckalloc(theSize);
+	    if (alias) {
+		AEGetDescData (&theDesc, alias, theSize);
+
+		theErr = FSResolveAlias(NULL, &alias,
+			&file, &dummy);
+		ckfree((char*)alias);
+	    } else {
+		theErr = memFullErr;
+	    }
 	    if (theErr == noErr) {
 		Tcl_DString scriptName;
-
 		theErr = FSRefToDString(&file, &scriptName);
 		if (theErr == noErr) {
-		    tclErr = Tcl_EvalFile(interp,
-			    Tcl_DStringValue(&scriptName));
+		    Tcl_EvalFile(interp, Tcl_DStringValue(&scriptName));
 		    Tcl_DStringFree(&scriptName);
 		}
 	    } else {
@@ -523,19 +557,9 @@ ScriptHandler(
 		AEPutParamPtr(reply, keyErrorString, typeChar,
 			errString, strlen(errString));
 	    }
-	} else if (AEGetParamPtr(event, keyDirectObject, typeUTF8Text, NULL,
-		NULL, 0, &size) == noErr && size) {
-	    char *data = ckalloc(size + 1);
-
-	    theErr = AEGetParamPtr(event, keyDirectObject, typeUTF8Text, NULL,
-		    data, size, NULL);
-	    if (theErr == noErr) {
-		tclErr = Tcl_EvalEx(interp, data, size, TCL_EVAL_GLOBAL);
-	    }
 	} else {
 	    sprintf(errString,
-		    "AEDoScriptHandler: invalid script type '%-4.4s', "
-		    "must be 'alis' or coercable to 'utf8'",
+		    "AEDoScriptHandler: invalid script type '%-4.4s', must be 'alis' or 'TEXT'",
 		    (char *)(&theDesc.descriptorType));
 	    AEPutParamPtr(reply, keyErrorString, typeChar,
 		    errString, strlen(errString));
@@ -555,7 +579,7 @@ ScriptHandler(
 	    AEPutParamPtr(reply, keyErrorString, typeChar,
 		Tcl_GetStringResult(interp),
 		strlen(Tcl_GetStringResult(interp)));
-	    AEPutParamPtr(reply, keyErrorNumber, typeSInt32,
+	    AEPutParamPtr(reply, keyErrorNumber, typeInteger,
 		(Ptr) &tclErr, sizeof(int));
 	}
     }
@@ -590,9 +614,9 @@ ReallyKillMe(
     Tcl_Interp *interp = ((KillEvent *) eventPtr)->interp;
     Tcl_CmdInfo dummy;
     if (Tcl_GetCommandInfo(interp, "::tk::mac::Quit", &dummy)) {
-	 Tcl_EvalEx(interp, "::tk::mac::Quit", -1, TCL_EVAL_GLOBAL);
+	 Tcl_GlobalEval(interp, "::tk::mac::Quit");
     } else {
-	Tcl_EvalEx(interp, "exit", -1, TCL_EVAL_GLOBAL);
+	Tcl_GlobalEval(interp, "exit");
     }
     return 1;
 }
@@ -621,8 +645,8 @@ MissedAnyParameters(
    Size actualSize;
    OSStatus err;
 
-   err = AEGetAttributePtr(theEvent, keyMissedKeywordAttr,
-	    typeWildCard, &returnedType, NULL, 0, &actualSize);
+   err = ChkErr(AEGetAttributePtr, theEvent, keyMissedKeywordAttr,
+	   typeWildCard, &returnedType, NULL, 0, &actualSize);
 
    return (err != errAEDescNotFound);
 }
