@@ -5,8 +5,10 @@
  *
  * Copyright (c) 1995-1996 Sun Microsystems, Inc.
  *
- * See the file "license.terms" for information on usage and redistribution
- * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ * See the file "license.terms" for information on usage and redistribution of
+ * this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ *
+ * RCS: @(#) $Id: xutil.c,v 1.4 2007/01/02 23:39:40 dkf Exp $
  */
 
 #include <stdlib.h>
@@ -20,10 +22,9 @@
  *
  * XInternAtom --
  *
- *	This procedure simulates the XInternAtom function by calling
- *	Tk_Uid to get a unique id for every atom.  This is only a
- *	partial implementation, since it doesn't work across
- *	applications.
+ *	This procedure simulates the XInternAtom function by calling Tk_Uid to
+ *	get a unique id for every atom. This is only a partial implementation,
+ *	since it doesn't work across applications.
  *
  * Results:
  *	A new Atom.
@@ -35,10 +36,10 @@
  */
 
 Atom
-XInternAtom(display, atom_name, only_if_exists)
-    Display* display;
-    _Xconst char* atom_name;
-    Bool only_if_exists;
+XInternAtom(
+    Display *display,
+    _Xconst char *atom_name,
+    Bool only_if_exists)
 {
     static Atom atom = XA_LAST_PREDEFINED;
 
@@ -63,13 +64,13 @@ XInternAtom(display, atom_name, only_if_exists)
  */
 
 XVisualInfo *
-XGetVisualInfo(display, vinfo_mask, vinfo_template, nitems_return)
-    Display* display;
-    long vinfo_mask;
-    XVisualInfo* vinfo_template;
-    int* nitems_return;
+XGetVisualInfo(
+    Display *display,
+    long vinfo_mask,
+    XVisualInfo *vinfo_template,
+    int *nitems_return)
 {
-    XVisualInfo *info = (XVisualInfo *)ckalloc(sizeof(XVisualInfo));
+    XVisualInfo *info = (XVisualInfo *) ckalloc(sizeof(XVisualInfo));
     info->visual = DefaultVisual(display, 0);
     info->visualid = info->visual->visualid;
     info->screen = 0;
@@ -107,3 +108,11 @@ XGetVisualInfo(display, vinfo_mask, vinfo_template, nitems_return)
     *nitems_return = 1;
     return info;
 }
+
+/*
+ * Local Variables:
+ * mode: c
+ * c-basic-offset: 4
+ * fill-column: 78
+ * End:
+ */
